@@ -12,32 +12,36 @@
 #' @param data A data frame.
 #' @param cols A tidy column selection,
 #'             e.g. a single column (without quotes)
-#'             or multiple columns selected by methods such as starts_with().
+#'             or multiple columns selected by methods such as `starts_with()`.
+#'             To calculate linear models, you can provide a formula
+#'             and skip the parameters for independent variables,
+#'             see the `model` parameter.
 #' @param cross Optional, a grouping or correlation column (without quotes).
 #' @param metric When crossing variables, the cross column parameter can contain categorical or metric values.
 #'            By default, the cross column selection is treated as categorical data.
-#'            Set metric to TRUE, to treat it as metric and calculate correlations.
-#'            Alternatively, for multivariable models (if the model parameter is TRUE),
+#'            Set metric to `TRUE`, to treat it as metric and calculate correlations.
+#'            Alternatively, for multivariable models (if the model parameter is `TRUE`),
 #'            provide the metric column selection in the metric parameter
 #'            and the categorical column selection in the cross parameter.
+#' @param interactions When model is set to `TRUE`, a vector of interaction effects to calculate. Will be passed to `add_model()`.
 #' @param ... Parameters passed to the \link{plot_metrics} and \link{tab_metrics} and \link{effect_metrics} functions.
 #' @param index When the cols contain items on a metric scale
 #'              (as determined by \link{get_direction}),
 #'              an index will be calculated using the 'psych' package.
-#'              Set to FALSE to suppress index generation.
+#'              Set to `FALSE` to suppress index generation.
 #' @param factors The number of factors to calculate.
-#'              Set to FALSE to suppress factor analysis.
-#'              Set to TRUE to output a scree plot and automatically choose the number of factors.
+#'              Set to `FALSE` to suppress factor analysis.
+#'              Set to `TRUE` to output a scree plot and automatically choose the number of factors.
 #'              When the cols contain items on a metric scale
 #'              (as determined by \link{get_direction}),
 #'              factors will be calculated using the 'psych' package.
 #'              See \link{add_factors}.
 #' @param clusters The number of clusters to calculate.
 #'                 Cluster are determined using kmeans after scaling the items.
-#'                Set to FALSE to suppress cluster analysis.
-#'                Set to TRUE to output a scree plot and automatically choose the number of clusters based on the elbow criterion.
+#'                Set to `FALSE` to suppress cluster analysis.
+#'                Set to `TRUE` to output a scree plot and automatically choose the number of clusters based on the elbow criterion.
 #'                 See \link{add_clusters}.
-#' @param model Set to TRUE for multivariable models.
+#' @param model Set to `TRUE` for multivariable models if you don't provide your model as a formula.
 #'              The dependent variable must be provided in the first parameter (cols).
 #'              Independent categorical variables are provided in the second parameter (cross),
 #'              which supports tidy column selections or vectors of multiple columns.
@@ -46,6 +50,8 @@
 #'              Interaction terms are provided in the interactions parameter and passed to the model functions.
 #'              You can get diagnostic plots by setting the diagnostics parameter to TRUE.
 #'              See \link{model_metrics_tab},  \link{model_metrics_plot} and  \link{add_model} for further options.
+#'              Instead of providing the model variables as cols, cross, metric and interactions parameters,
+#'              you can pass a model formula compatile with  \code{stats::\link[stats:lm]{lm}} to the cols parameter,
 #' @param effect Whether to report statistical tests and effect sizes. See \link{effect_counts} for further parameters.
 #' @param title A character providing the heading or TRUE (default) to output a heading.
 #'               Classes for tabset pills will be added.
@@ -61,18 +67,57 @@
 #' report_metrics(data, sd_age)
 #'
 #' @export
-report_metrics <- function(data, cols, cross = NULL, metric = FALSE, ..., index = FALSE, factors = FALSE, clusters = FALSE, model = FALSE, effect = FALSE, title = TRUE, close = TRUE, clean = TRUE) {
+report_metrics <- function(data, cols, cross = NULL, metric = FALSE, interactions = NULL, ..., index = FALSE, factors = FALSE, clusters = FALSE, model = FALSE, effect = FALSE, title = TRUE, close = TRUE, clean = TRUE) {
 
   if (clean) {
     data <- data_clean(data, clean)
   }
 
+  col_q <- rlang::enquo(cols)
+  fun_mode <- rlang::quo_is_call(col_q, "~")
+
+  # Formula mode
+  if (fun_mode) {
+    terms <- .extract_terms_from_formula(rlang::eval_tidy(col_q), data)
+
+    model <- TRUE
+    cols <-  rlang::sym(terms$lhs)
+    cross <- NULL
+
+  }
+
+  # Tidyselect mode
+  else {
+    cols <- rlang::enquo(cols)
+    cross <- rlang::enquo(cross)
+
+    if (model) {
+
+      # Handle FALSE
+      if ((!rlang::quo_is_symbol(rlang::enquo(metric)) && rlang::as_label(rlang::enquo(metric)) == "FALSE")) {
+        metric <- NULL
+      }
+
+      terms <- list(
+        categorical = rlang::enquo(cross),
+        metric = rlang::enquo(metric),
+        interactions = rlang::enquo(interactions)
+      )
+    }
+  }
+
+  # For modeling: Only show descriptives of outcome variable
+  if (model) {
+      cross <- NULL
+      metric <-  FALSE
+  }
+
   chunks <- list()
 
   # Add title
   if (!is.null(knitr::pandoc_to())) {
     if (!is.character(title) && (title == TRUE)) {
-      title <- get_title(data, {{ cols }})
+      title <- get_title(data, !!cols)
     } else if (!is.character(title)) {
       title <- ""
     }
@@ -83,36 +128,23 @@ report_metrics <- function(data, cols, cross = NULL, metric = FALSE, ..., index
     plot_title <- title
   }
 
-  # Prepare modeling
-  if (model) {
-    model.categorical <- rlang::enquo(cross)
-    model.metric <- rlang::enquo(metric)
-
-    if ((!rlang::quo_is_symbol(model.metric) && rlang::as_label(model.metric) == "FALSE")) {
-      model.metric <- NULL
-    }
-
-    metric <-  FALSE
-    cross <- NULL
-  }
-
   # Add Plot
-  chunks <- plot_metrics(data, {{ cols }}, {{ cross }}, metric = metric, effect = effect, clean = clean, ..., title = plot_title) %>%
+  chunks <- plot_metrics(data, !!cols, !!cross, metric = metric, effect = effect, clean = clean, ..., title = plot_title) %>%
     .add_to_vlkr_rprt(chunks, "Plot")
 
   # Add table
-  chunks <- tab_metrics(data, {{ cols}}, {{ cross }}, metric = metric, effect = effect, clean=clean, ...) %>%
+  chunks <- tab_metrics(data, !!cols, !!cross, metric = metric, effect = effect, clean=clean, ...) %>%
     .add_to_vlkr_rprt(chunks, "Table")
 
   # Add effect sizes
   if (effect) {
-    chunks <- effect_metrics(data, {{ cols }}, {{ cross }}, metric = metric, effect = effect, clean=clean, ...) %>%
+    chunks <- effect_metrics(data, !!cols, !!cross, metric = metric, effect = effect, clean=clean, ...) %>%
       .add_to_vlkr_rprt(chunks, "Effects")
   }
 
   # Add index
   if (index) {
-    idx <- .report_idx(data, {{ cols }}, {{ cross }}, metric = metric, ..., effect = effect, title = plot_title)
+    idx <- .report_idx(data, !!cols, !!cross, metric = metric, ..., effect = effect, title = plot_title)
     chunks <- append(chunks, idx)
   }
 
@@ -121,7 +153,7 @@ report_metrics <- function(data, cols, cross = NULL, metric = FALSE, ..., index
     if (factors == TRUE) {
       factors <- NULL
     }
-    fct <- .report_fct(data, {{ cols }}, {{ cross }}, metric = metric, k = factors, ..., effect = effect, title = plot_title)
+    fct <- .report_fct(data, !!cols, !!cross, metric = metric, k = factors, ..., effect = effect, title = plot_title)
     chunks <- append(chunks, fct)
   }
 
@@ -130,13 +162,13 @@ report_metrics <- function(data, cols, cross = NULL, metric = FALSE, ..., index
     if (all(clusters == TRUE)) {
       clusters <- NULL
     }
-    fct <- .report_cls(data, {{ cols }}, {{ cross }}, metric = metric, k = clusters, ..., effect = effect, title = plot_title)
+    fct <- .report_cls(data, !!cols, !!cross, metric = metric, k = clusters, ..., effect = effect, title = plot_title)
     chunks <- append(chunks, fct)
   }
 
   # Add model
   if (!any(isFALSE(model))) {
-    mdl <- .report_mdl(data,{{ cols }}, categorical = !!model.categorical, metric = !!model.metric, ..., title = plot_title)
+    mdl <- .report_mdl(data, !!cols, categorical = !!terms$categorical, metric = !!terms$metric, interactions = !!terms$interactions, ..., title = plot_title)
     chunks <- append(chunks, mdl)
   }
 
@@ -399,7 +431,7 @@ report_counts <- function(data, cols, cross = NULL, metric = FALSE, ids = NULL,
 
   if (is_items && (is_scale != 0)) {
 
-    scores <- add_clusters(data, {{ cols }}, k = k, ...)
+    scores <- add_clusters(data, {{ cols }}, newcol = NULL, k = k, method = "kmeans", ...)
     newcol <- setdiff(colnames(scores), colnames(data))
 
     plt <- cluster_plot(scores, !!sym(newcol), k = k,  ...)
@@ -421,14 +453,14 @@ report_counts <- function(data, cols, cross = NULL, metric = FALSE, ids = NULL,
 #' @param cols A a single column (without quotes).
 #' @param categorical A tidy column selection holding independet categorical variables.
 #' @param metric A tidy column selection holding independent metric variables.
-#'
+#' @param interactions A vector of interaction effects to calculate, passed to `add_model()`.
 #' @param title Add a plot title (default = TRUE).
 #' @return A list containing a table and a plot volker report chunk.
-.report_mdl <- function(data, cols, categorical = NULL, metric = NULL, ..., title = TRUE) {
+.report_mdl <- function(data, cols, categorical = NULL, metric = NULL, interactions = NULL, ..., title = TRUE) {
   chunks <- list()
 
-  scores <- add_model(data, {{ cols }}, {{ categorical }}, {{ metric }}, ...)
-  newcol <- names(scores)[ncol(scores)] # Last col
+  scores <- add_model(data, !!enquo(cols), !!enquo(categorical), !!enquo(metric), !!enquo(interactions), newcol = ".prd", ...)
+  newcol <- setdiff(colnames(scores), colnames(data))
 
   plt <- model_plot(scores, tidyselect::all_of(newcol),  ...)
   chunks <- .add_to_vlkr_rprt(plt, chunks, "Model: Plot")
